==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/km-KH/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'អ្នកប្រើប្រាស់នេះអាចចូលបាន។',
    'activated_disabled_help_text' => 'អ្នកមិនអាចកែសម្រួលស្ថានភាពធ្វើឱ្យសកម្មសម្រាប់គណនីផ្ទាល់ខ្លួនរបស់អ្នកបានទេ។',
    'assets_user'       => 'ទ្រព្យ​សម្បត្តិ​ដែល​ត្រូវ​បាន​ចាត់​ឱ្យ​ទៅ​: ឈ្មោះ​',
    'bulk_update_warn'	=> 'អ្នកហៀបនឹងកែសម្រួលលក្ខណៈសម្បត្តិរបស់ :user_count អ្នកប្រើប្រាស់។ សូមចំណាំថា អ្នកមិនអាចផ្លាស់ប្តូរលក្ខណៈអ្នកប្រើប្រាស់ផ្ទាល់ខ្លួនរបស់អ្នកដោយប្រើទម្រង់នេះ ហើយត្រូវតែធ្វើការកែសម្រួលអ្នកប្រើប្រាស់ផ្ទាល់ខ្លួនរបស់អ្នកជាលក្ខណៈបុគ្គល។',
    'bulk_update_help'	=> 'ទម្រង់បែបបទនេះអនុញ្ញាតឱ្យអ្នកធ្វើបច្ចុប្បន្នភាពអ្នកប្រើប្រាស់ច្រើននាក់ក្នុងពេលតែមួយ។ បំពេញតែក្នុងវាលដែលអ្នកត្រូវការផ្លាស់ប្តូរ។ វាល​ណា​មួយ​ដែល​ទុក​ឲ្យ​ទទេ​នឹង​នៅ​តែ​មិន​ផ្លាស់​ប្តូរ។',
    'current_assets'    => 'Assets currently checked out to this user',
    'clone'             => 'ក្លូន អ្នកប្រើប្រាស់',
    'contact_user'      => 'ទំនាក់ទំនងៈ ឈ្មោះ​',
    'edit'              => 'កែសម្រួលអ្នកប្រើប្រាស់',
    'filetype_info'     => 'ប្រភេទឯកសារដែលបានអនុញ្ញាតគឺ png, gif, jpg, jpeg, doc, docx, pdf, txt, zip និង rar ។',
    'history_user'      => 'ប្រវត្តិសម្រាប់៖ ឈ្មោះ',
    'info'				=> 'ព័ត៌មាន',
    'restore_user'		=> 'ចុចទីនេះដើម្បីស្ដារពួកវាឡើងវិញ។',
    'last_login'        => 'ការចូលចុងក្រោយ',
    'ldap_config_text'  => 'ការកំណត់រចនាសម្ព័ន្ធ LDAP អាចត្រូវបានរកឃើញ អ្នកគ្រប់គ្រង > ការកំណត់។ ទីតាំងដែលបានជ្រើសរើស (ជាជម្រើស) នឹងត្រូវបានកំណត់សម្រាប់អ្នកប្រើប្រាស់ដែលបាននាំចូលទាំងអស់។',
    'print_assigned'    => 'បោះពុម្ពដែលបានចាត់តាំងទាំងអស់។',
    'email_assigned'    => 'បញ្ជីអ៊ីមែលដែលបានចាត់តាំងទាំងអស់។',
    'user_notified'     => 'អ្នក​ប្រើ​ត្រូវ​បាន​ផ្ញើ​អ៊ីមែល​នូវ​បញ្ជី​នៃ​ធាតុ​ដែល​បាន​កំណត់​បច្ចុប្បន្ន​របស់​ពួកគេ។',
    'auto_assign_label' => 'រួមបញ្ចូលអ្នកប្រើប្រាស់នេះនៅពេលផ្តល់អាជ្ញាប័ណ្ណដែលមានសិទ្ធិដោយស្វ័យប្រវត្តិ',
    'auto_assign_help'  => 'រំលងអ្នកប្រើប្រាស់នេះក្នុងការផ្តល់អាជ្ញាប័ណ្ណដោយស្វ័យប្រវត្តិ',
    'software_user'     => 'Software Checked out to :name',
    'send_email_help'   => 'អ្នក​ត្រូវ​តែ​ផ្តល់​អាសយដ្ឋាន​អ៊ីមែល​សម្រាប់​អ្នក​ប្រើ​នេះ​ដើម្បី​ផ្ញើ​ព័ត៌មាន​សម្ងាត់​ឱ្យ​ពួកគេ​។ ការផ្ញើអត្តសញ្ញាណប័ណ្ណតាមអ៊ីមែលអាចធ្វើបានតែលើការបង្កើតអ្នកប្រើប្រាស់ប៉ុណ្ណោះ។ ពាក្យ​សម្ងាត់​ត្រូវ​បាន​រក្សា​ទុក​ជា​សញ្ញា​មួយ​ផ្លូវ ហើយ​មិន​អាច​ទាញ​យក​វិញ​បាន​ទេ​ពេល​រក្សា​ទុក។',
    'view_user'         => 'មើលអ្នកប្រើប្រាស់៖ ឈ្មោះ',
    'usercsv'           => 'ឯកសារ CSV',
    'two_factor_admin_optin_help' => 'ការកំណត់អ្នកគ្រប់គ្រងបច្ចុប្បន្នរបស់អ្នកអនុញ្ញាតឱ្យមានការជ្រើសរើសនៃការផ្ទៀងផ្ទាត់ពីរកត្តា។  ',
    'two_factor_enrolled' => 'ឧបករណ៍ 2FA បានចុះឈ្មោះ ',
    'two_factor_active'   => '2FA សកម្ម ',
    'user_deactivated'  => 'អ្នកប្រើប្រាស់មិនអាចចូលបានទេ',
    'user_activated'  => 'អ្នកប្រើប្រាស់អាចចូលបាន',
    'activation_status_warning' => 'កុំផ្លាស់ប្តូរស្ថានភាពធ្វើឱ្យសកម្ម',
    'group_memberships_helpblock' => 'មានតែអ្នកគ្រប់គ្រងជាន់ខ្ពស់ប៉ុណ្ណោះដែលអាចកែសម្រួលសមាជិកភាពក្រុម។',
    'superadmin_permission_warning' => 'មានតែ superadmins ប៉ុណ្ណោះដែលអាចផ្តល់សិទ្ធិចូលប្រើ superadmin អ្នកប្រើប្រាស់។',
    'admin_permission_warning' => 'មាន​តែ​អ្នក​ប្រើ​ដែល​មាន​សិទ្ធិ​ជា​អ្នក​គ្រប់គ្រង ឬ​ខ្ពស់​ជាង​នេះ​ប៉ុណ្ណោះ​ដែល​អាច​ផ្ដល់​សិទ្ធិ​ឱ្យ​អ្នក​ប្រើ​ជា​អ្នក​គ្រប់គ្រង។',
    'remove_group_memberships' => 'ដកសមាជិកភាពក្រុមចេញ',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'អាប់ដេតទ្រព្យសកម្មទាំងអស់សម្រាប់អ្នកប្រើប្រាស់ទាំងនេះទៅកាន់ស្ថានភាពនេះ។',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'នេះគឺជាអ្នកប្រើប្រាស់ពីចម្ងាយ',
    'remote'   => 'ពីចម្ងាយ',
    'remote_help' => 'វាអាចមានប្រយោជន៍ ប្រសិនបើអ្នកត្រូវការត្រងដោយអ្នកប្រើប្រាស់ពីចម្ងាយ ដែលមិនដែល ឬកម្រចូលមកក្នុងទីតាំងជាក់ស្តែងរបស់អ្នក។',
    'not_remote_label' => 'នេះមិនមែនជាអ្នកប្រើប្រាស់ពីចម្ងាយទេ។',
    'vip_label' => 'អ្នកប្រើប្រាស់ VIP',
    'vip_help' => 'វាអាចមានប្រយោជន៍ក្នុងការសម្គាល់មនុស្សសំខាន់ៗនៅក្នុងអង្គការរបស់អ្នក ប្រសិនបើអ្នកចង់ដោះស្រាយពួកគេតាមវិធីពិសេស។',
    'create_user' => 'បង្កើតអ្នកប្រើប្រាស់',
    'create_user_page_explanation' => 'នេះគឺជាព័ត៌មានគណនីដែលអ្នកនឹងប្រើដើម្បីចូលប្រើគេហទំព័រនេះជាលើកដំបូង។',
    'email_credentials' => 'លិខិតសម្គាល់អ៊ីមែល',
    'email_credentials_text' => 'ផ្ញើ​អ៊ីមែល​ព័ត៌មាន​សម្ងាត់​របស់​ខ្ញុំ​ទៅ​អាសយដ្ឋាន​អ៊ីមែល​ខាង​លើ',
    'next_save_user' => 'បន្ទាប់៖ រក្សាទុកអ្នកប្រើប្រាស់',
    'all_assigned_list_generation' => 'បង្កើតនៅលើ៖',
    'email_user_creds_on_create' => 'ផ្ញើអ៊ីមែលទៅអ្នកប្រើប្រាស់នេះនូវអត្តសញ្ញាណប័ណ្ណរបស់ពួកគេ?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/km-KH/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'អ្នកប្រើប្រាស់នេះអាចចូលបាន។',
    'activated_disabled_help_text' => 'អ្នកមិនអាចកែសម្រួលស្ថានភាពធ្វើឱ្យសកម្មសម្រាប់គណនីផ្ទាល់ខ្លួនរបស់អ្នកបានទេ។',
    'assets_user'       => 'ទ្រព្យ​សម្បត្តិ​ដែល​ត្រូវ​បាន​ចាត់​ឱ្យ​ទៅ​: ឈ្មោះ​',
    'bulk_update_warn'	=> 'អ្នកហៀបនឹងកែសម្រួលលក្ខណៈសម្បត្តិរបស់ :user_count អ្នកប្រើប្រាស់។ សូមចំណាំថា អ្នកមិនអាចផ្លាស់ប្តូរលក្ខណៈអ្នកប្រើប្រាស់ផ្ទាល់ខ្លួនរបស់អ្នកដោយប្រើទម្រង់នេះ ហើយត្រូវតែធ្វើការកែសម្រួលអ្នកប្រើប្រាស់ផ្ទាល់ខ្លួនរបស់អ្នកជាលក្ខណៈបុគ្គល។',
    'bulk_update_help'	=> 'ទម្រង់បែបបទនេះអនុញ្ញាតឱ្យអ្នកធ្វើបច្ចុប្បន្នភាពអ្នកប្រើប្រាស់ច្រើននាក់ក្នុងពេលតែមួយ។ បំពេញតែក្នុងវាលដែលអ្នកត្រូវការផ្លាស់ប្តូរ។ វាល​ណា​មួយ​ដែល​ទុក​ឲ្យ​ទទេ​នឹង​នៅ​តែ​មិន​ផ្លាស់​ប្តូរ។',
    'current_assets'    => 'បច្ចុប្បន្នទ្រព្យសកម្មបានប្រគល់អោយទៅកាន់អ្នកប្រើប្រាស់នេះ។',
    'clone'             => 'ក្លូន អ្នកប្រើប្រាស់',
    'contact_user'      => 'ទំនាក់ទំនងៈ ឈ្មោះ​',
    'edit'              => 'កែសម្រួលអ្នកប្រើប្រាស់',
    'filetype_info'     => 'ប្រភេទឯកសារដែលបានអនុញ្ញាតគឺ png, gif, jpg, jpeg, doc, docx, pdf, txt, zip និង rar ។',
    'history_user'      => 'ប្រវត្តិសម្រាប់៖ ឈ្មោះ',
    'info'				=> 'ព័ត៌មាន',
    'restore_user'		=> 'ចុចទីនេះដើម្បីស្ដារពួកវាឡើងវិញ។',
    'last_login'        => 'ការចូលចុងក្រោយ',
    'ldap_config_text'  => 'ការកំណត់រចនាសម្ព័ន្ធ LDAP អាចត្រូវបានរកឃើញ អ្នកគ្រប់គ្រង > ការកំណត់។ ទីតាំងដែលបានជ្រើសរើស (ជាជម្រើស) នឹងត្រូវបានកំណត់សម្រាប់អ្នកប្រើប្រាស់ដែលបាននាំចូលទាំងអស់។',
    'print_assigned'    => 'បោះពុម្ពដែលបានចាត់តាំងទាំងអស់។',
    'email_assigned'    => 'បញ្ជីអ៊ីមែលដែលបានចាត់តាំងទាំងអស់។',
    'user_notified'     => 'អ្នក​ប្រើ​ត្រូវ​បាន​ផ្ញើ​អ៊ីមែល​នូវ​បញ្ជី​នៃ​ធាតុ​ដែល​បាន​កំណត់​បច្ចុប្បន្ន​របស់​ពួកគេ។',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'រួមបញ្ចូលអ្នកប្រើប្រាស់នេះនៅពេលផ្តល់អាជ្ញាប័ណ្ណដែលមានសិទ្ធិដោយស្វ័យប្រវត្តិ',
    'auto_assign_help'  => 'រំលងអ្នកប្រើប្រាស់នេះក្នុងការផ្តល់អាជ្ញាប័ណ្ណដោយស្វ័យប្រវត្តិ',
    'software_user'     => 'កម្មវិធីដែលបានប្រគល់ទៅកាន់៖ ឈ្មោះ',
    'send_email_help'   => 'អ្នក​ត្រូវ​តែ​ផ្តល់​អាសយដ្ឋាន​អ៊ីមែល​សម្រាប់​អ្នក​ប្រើ​នេះ​ដើម្បី​ផ្ញើ​ព័ត៌មាន​សម្ងាត់​ឱ្យ​ពួកគេ​។ ការផ្ញើអត្តសញ្ញាណប័ណ្ណតាមអ៊ីមែលអាចធ្វើបានតែលើការបង្កើតអ្នកប្រើប្រាស់ប៉ុណ្ណោះ។ ពាក្យ​សម្ងាត់​ត្រូវ​បាន​រក្សា​ទុក​ជា​សញ្ញា​មួយ​ផ្លូវ ហើយ​មិន​អាច​ទាញ​យក​វិញ​បាន​ទេ​ពេល​រក្សា​ទុក។',
    'view_user'         => 'មើលអ្នកប្រើប្រាស់៖ ឈ្មោះ',
    'usercsv'           => 'ឯកសារ CSV',
    'two_factor_admin_optin_help' => 'ការកំណត់អ្នកគ្រប់គ្រងបច្ចុប្បន្នរបស់អ្នកអនុញ្ញាតឱ្យមានការជ្រើសរើសនៃការផ្ទៀងផ្ទាត់ពីរកត្តា។  ',
    'two_factor_enrolled' => 'ឧបករណ៍ 2FA បានចុះឈ្មោះ ',
    'two_factor_active'   => '2FA សកម្ម ',
    'user_deactivated'  => 'អ្នកប្រើប្រាស់មិនអាចចូលបានទេ',
    'user_activated'  => 'អ្នកប្រើប្រាស់អាចចូលបាន',
    'activation_status_warning' => 'កុំផ្លាស់ប្តូរស្ថានភាពធ្វើឱ្យសកម្ម',
    'group_memberships_helpblock' => 'មានតែអ្នកគ្រប់គ្រងជាន់ខ្ពស់ប៉ុណ្ណោះដែលអាចកែសម្រួលសមាជិកភាពក្រុម។',
    'superadmin_permission_warning' => 'មានតែ superadmins ប៉ុណ្ណោះដែលអាចផ្តល់សិទ្ធិចូលប្រើ superadmin អ្នកប្រើប្រាស់។',
    'admin_permission_warning' => 'មាន​តែ​អ្នក​ប្រើ​ដែល​មាន​សិទ្ធិ​ជា​អ្នក​គ្រប់គ្រង ឬ​ខ្ពស់​ជាង​នេះ​ប៉ុណ្ណោះ​ដែល​អាច​ផ្ដល់​សិទ្ធិ​ឱ្យ​អ្នក​ប្រើ​ជា​អ្នក​គ្រប់គ្រង។',
    'remove_group_memberships' => 'ដកសមាជិកភាពក្រុមចេញ',
    'warning_deletion_information' => 'អ្នកហៀបនឹងប្រគល់ត្រលប់វិញធាតុទាំងអស់ពី :count user(s) ដែលបានរាយខាងក្រោម។ ឈ្មោះអ្នកគ្រប់គ្រងជាន់ខ្ពស់ត្រូវបានបន្លិចជាពណ៌ក្រហម។',
    'update_user_assets_status' => 'អាប់ដេតទ្រព្យសកម្មទាំងអស់សម្រាប់អ្នកប្រើប្រាស់ទាំងនេះទៅកាន់ស្ថានភាពនេះ។',
    'checkin_user_properties' => 'ប្រគល់មកវិញលក្ខណៈសម្បត្តិទាំងអស់ដែលទាក់ទងនឹងអ្នកប្រើប្រាស់ទាំងនេះ',
    'remote_label'   => 'នេះគឺជាអ្នកប្រើប្រាស់ពីចម្ងាយ',
    'remote'   => 'ពីចម្ងាយ',
    'remote_help' => 'វាអាចមានប្រយោជន៍ ប្រសិនបើអ្នកត្រូវការត្រងដោយអ្នកប្រើប្រាស់ពីចម្ងាយ ដែលមិនដែល ឬកម្រចូលមកក្នុងទីតាំងជាក់ស្តែងរបស់អ្នក។',
    'not_remote_label' => 'នេះមិនមែនជាអ្នកប្រើប្រាស់ពីចម្ងាយទេ។',
    'vip_label' => 'អ្នកប្រើប្រាស់ VIP',
    'vip_help' => 'វាអាចមានប្រយោជន៍ក្នុងការសម្គាល់មនុស្សសំខាន់ៗនៅក្នុងអង្គការរបស់អ្នក ប្រសិនបើអ្នកចង់ដោះស្រាយពួកគេតាមវិធីពិសេស។',
    'create_user' => 'បង្កើតអ្នកប្រើប្រាស់',
    'create_user_page_explanation' => 'នេះគឺជាព័ត៌មានគណនីដែលអ្នកនឹងប្រើដើម្បីចូលប្រើគេហទំព័រនេះជាលើកដំបូង។',
    'email_credentials' => 'លិខិតសម្គាល់អ៊ីមែល',
    'email_credentials_text' => 'ផ្ញើ​អ៊ីមែល​ព័ត៌មាន​សម្ងាត់​របស់​ខ្ញុំ​ទៅ​អាសយដ្ឋាន​អ៊ីមែល​ខាង​លើ',
    'next_save_user' => 'បន្ទាប់៖ រក្សាទុកអ្នកប្រើប្រាស់',
    'all_assigned_list_generation' => 'បង្កើតនៅលើ៖',
    'email_user_creds_on_create' => 'ផ្ញើអ៊ីមែលទៅអ្នកប្រើប្រាស់នេះនូវអត្តសញ្ញាណប័ណ្ណរបស់ពួកគេ?',
];
